//LabPlot : manipulations.h
// sync with labplot.qs

#ifndef MANIPULATIONS_H
#define MANIPULATIONS_H

// TODO : annotate, convolve, frame, opaque, unsharpmask
enum ManipulationType {ADAPTIVETHRESHOLD,ADDNOISE,BLUR,BORDER,CHARCOAL,CHOP,COLORIZE,CONTRAST,
CYCLECOLORMAP,DESPECKLE,EDGE,EMBOSS, ENHANCE, EQUALIZE,ERASE,FLIP,FLOODFILLCOLOR,FLOP,MGAMMA,
GAUSSIANBLUR,IMPLODE,MAGNIFY,MEDIANFILTER,MINIFY,MODULATE,NEGATE,NORMALIZE,OILPAINT,OPACITY,
QUANTIZE,RAISE,REDUCENOISE,ROLL,ROTATE,SAMPLE,SCALE,SEGMENT,SHADE,SHARPEN,SHAVE,SHEAR,SOLARIZE,
SPREAD,SWIRL,THRESHOLD,TRANSFORM,TRANSPARENT,TRIM,WAVE,ZOOM};
static const char *typeitems[] = {"adaptive threshold","add noise","blur","border","charcoal","chop","colorize","contrast",
"cycle colormap","despeckle","edge","emboss","enhance","equalize","erase","flip","flood fill color","flop","gamma",
"gaussian blur","implode","magnify","median filter","minify","modulate","negate","normalize","oil paint","opacity",
"quantize","raise","reduce noise","roll","rotate","sample","scale","segment","shade","sharpen","shave","shear","solarize",
"spread","swirl","threshold","transform","transparent","trim","wave","zoom",0};


#endif // MANIPULATIONS_H
